@@ -5,13 +5,14 @@ from Cython.Build import cythonize
 
 setup(
     name="NBCPU-Pipeline",
-    ext_modules=cythonize("Source/*.py"),
+    ext_modules=cythonize("*.py"),
     description="Parallel Threading Utilizing Common CPU Procedures",
     author="Alex",
-    author_email="obfuscate@riseup.net"
+    author_email="obfuscate@riseup.net",
+    
 )
 
-for i in os.listdir('Source/'):
+for i in os.listdir('.'):
     if(i.endswith('.c')):
-        os.remove('Source/' + i)
+        os.remove(i)
 
